#!/usr/bin/env python

"""
GPIO example layout
v5

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="GPIO" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    et.transceive('dt x=13 y=34 bw=26 t="Pin" ld=l a=c;', echo=True)
    et.transceive('dt x=50 y=34 bw=39 t="Mode" ld=l a=c;', echo=True)
    et.transceive('dt x=95 y=34 bw=46 t="Pull" ld=l a=c;', echo=True)
    et.transceive('dt x=175 y=34 bw=100 t="Output" ld=l a=c;', echo=True)
    et.transceive('dt x=267 y=34 bw=75 t="Input" ld=l a=c;', echo=True)
    
    #G0
    et.transceive('dt x=7 y=58 f=22b t="0" a=l;', echo=True)
    et.transceive('db x=30 y=50 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G0 m=d|G0 m=i|G0 m=o";', echo=True)
    et.transceive('db x=71 y=50 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G0 pp=no|G0 pp=up|G0 pp=down";', echo=True)
    et.transceive('db x=125 y=50 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G0 ot=pp|G0 ot=od";', echo=True)
    et.transceive('db x=186 y=50 c=0,0,100 w=40 h=39 t="0|1" a="G0 os=0|G0 os=1";', echo=True)
    et.transceive('db x=230 y=50 c=0,0,100 w=50 h=39 t="Read" a="G0 is=?";', echo=True)
    et.transceive('df x=280 y=58 ft=vo f=22b w=40 h=39 pm="G0 is=%d\\r\\n";', echo=True)
    
    #G1
    et.transceive('dt x=7 y=98 f=22b t="1" a=l;', echo=True)
    et.transceive('db x=30 y=90 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G1 m=d|G1 m=i|G1 m=o";', echo=True)
    et.transceive('db x=71 y=90 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G1 pp=no|G1 pp=up|G1 pp=down";', echo=True)
    et.transceive('db x=125 y=90 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G1 ot=pp|G1 ot=od";', echo=True)
    et.transceive('db x=186 y=90 c=0,0,100 w=40 h=39 t="0|1" a="G1 os=0|G1 os=1";', echo=True)
    et.transceive('db x=230 y=90 c=0,0,100 w=50 h=39 t="Read" a="G1 is=?";', echo=True)
    et.transceive('df x=280 y=98 ft=vo f=22b w=40 h=39 pm="G1 is=%d\\r\\n";', echo=True)
    
    #G2
    et.transceive('dt x=7 y=138 f=22b t="2" a=l;', echo=True)
    et.transceive('db x=30 y=130 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G2 m=d|G2 m=i|G2 m=o";', echo=True)
    et.transceive('db x=71 y=130 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G2 pp=no|G2 pp=up|G2 pp=down";', echo=True)
    et.transceive('db x=125 y=130 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G2 ot=pp|G2 ot=od";', echo=True)
    et.transceive('db x=186 y=130 c=0,0,100 w=40 h=39 t="0|1" a="G2 os=0|G2 os=1";', echo=True)
    et.transceive('db x=230 y=130 c=0,0,100 w=50 h=39 t="Read" a="G2 is=?";', echo=True)
    et.transceive('df x=280 y=138 ft=vo f=22b w=40 h=39 pm="G2 is=%d\\r\\n";', echo=True)
    
    #G3
    et.transceive('dt x=7 y=178 f=22b t="3" a=l;', echo=True)
    et.transceive('db x=30 y=170 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G3 m=d|G3 m=i|G3 m=o";', echo=True)
    et.transceive('db x=71 y=170 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G3 pp=no|G3 pp=up|G3 pp=down";', echo=True)
    et.transceive('db x=125 y=170 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G3 ot=pp|G3 ot=od";', echo=True)
    et.transceive('db x=186 y=170 c=0,0,100 w=40 h=39 t="0|1" a="G3 os=0|G3 os=1";', echo=True)
    et.transceive('db x=230 y=170 c=0,0,100 w=50 h=39 t="Read" a="G3 is=?";', echo=True)
    et.transceive('df x=280 y=178 ft=vo f=22b w=40 h=39 pm="G3 is=%d\\r\\n";', echo=True)
    
    #G4
    et.transceive('dt x=7 y=218 f=22b t="4" a=l;', echo=True)
    et.transceive('db x=30 y=210 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G4 m=d|G4 m=i|G4 m=o";', echo=True)
    et.transceive('db x=71 y=210 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G4 pp=no|G4 pp=up|G4 pp=down";', echo=True)
    et.transceive('db x=125 y=210 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G4 ot=pp|G4 ot=od";', echo=True)
    et.transceive('db x=186 y=210 c=0,0,100 w=40 h=39 t="0|1" a="G4 os=0|G4 os=1";', echo=True)
    et.transceive('db x=230 y=210 c=0,0,100 w=50 h=39 t="Read" a="G4 is=?";', echo=True)
    et.transceive('df x=280 y=218 ft=vo f=22b w=40 h=39 pm="G4 is=%d\\r\\n";', echo=True)
    
    #G5
    et.transceive('dt x=7 y=258 f=22b t="5" a=l;', echo=True)
    et.transceive('db x=30 y=250 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G5 m=d|G5 m=i|G5 m=o";', echo=True)
    et.transceive('db x=71 y=250 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G5 pp=no|G5 pp=up|G5 pp=down";', echo=True)
    et.transceive('db x=125 y=250 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G5 ot=pp|G5 ot=od";', echo=True)
    et.transceive('db x=186 y=250 c=0,0,100 w=40 h=39 t="0|1" a="G5 os=0|G5 os=1";', echo=True)
    et.transceive('db x=230 y=250 c=0,0,100 w=50 h=39 t="Read" a="G5 is=?";', echo=True)
    et.transceive('df x=280 y=258 ft=vo f=22b w=40 h=39 pm="G5 is=%d\\r\\n";', echo=True)
    
    #G6
    et.transceive('dt x=7 y=298 f=22b t="6" a=l;', echo=True)
    et.transceive('db x=30 y=290 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G6 m=d|G6 m=i|G6 m=o";', echo=True)
    et.transceive('db x=71 y=290 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G6 pp=no|G6 pp=up|G6 pp=down";', echo=True)
    et.transceive('db x=125 y=290 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G6 ot=pp|G6 ot=od";', echo=True)
    et.transceive('db x=186 y=290 c=0,0,100 w=40 h=39 t="0|1" a="G6 os=0|G6 os=1";', echo=True)
    et.transceive('db x=230 y=290 c=0,0,100 w=50 h=39 t="Read" a="G6 is=?";', echo=True)
    et.transceive('df x=280 y=298 ft=vo f=22b w=40 h=39 pm="G6 is=%d\\r\\n";', echo=True)
    
    #G7
    et.transceive('dt x=7 y=338 f=22b t="7" a=l;', echo=True)
    et.transceive('db x=30 y=330 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G7 m=d|G7 m=i|G7 m=o";', echo=True)
    et.transceive('db x=71 y=330 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G7 pp=no|G7 pp=up|G7 pp=down";', echo=True)
    et.transceive('db x=125 y=330 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G7 ot=pp|G7 ot=od";', echo=True)
    et.transceive('db x=186 y=330 c=0,0,100 w=40 h=39 t="0|1" a="G7 os=0|G7 os=1";', echo=True)
    et.transceive('db x=230 y=330 c=0,0,100 w=50 h=39 t="Read" a="G7 is=?";', echo=True)
    et.transceive('df x=280 y=338 ft=vo f=22b w=40 h=39 pm="G7 is=%d\\r\\n";', echo=True)
    
    #G8
    et.transceive('dt x=7 y=378 f=22b t="8" a=l;', echo=True)
    et.transceive('db x=30 y=370 c=0,0,100 w=40 h=39 t="Hi-Z|Input|Output" a="G8 m=d|G8 m=i|G8 m=o";', echo=True)
    et.transceive('db x=71 y=370 c=0,0,100 w=50 h=39 t="NoPull|PullUp|PullDown" a="G8 pp=no|G8 pp=up|G8 pp=down";', echo=True)
    et.transceive('db x=125 y=370 c=0,0,100 w=60 h=39 t="PushPull|OpenDrain" a="G8 ot=pp|G8 ot=od";', echo=True)
    et.transceive('db x=186 y=370 c=0,0,100 w=40 h=39 t="0|1" a="G8 os=0|G8 os=1";', echo=True)
    et.transceive('db x=230 y=370 c=0,0,100 w=50 h=39 t="Read" a="G8 is=?";', echo=True)
    et.transceive('df x=280 y=378 ft=vo f=22b w=40 h=39 pm="G8 is=%d\\r\\n";', echo=True)
    
    #Read all inputs
    et.transceive('db x=30 y=410 c=0,0,100 w=91 h=40 t="Read all periodic" a="SYS coae=1+TIM a=\\"G0 is=?+G1 is=?+G2 is=?+G3 is=?+G4 is=?+G5 is=?+G6 is=?+G7 is=?+G8 is=?\\" p=100 s=1";', echo=True)
    et.transceive('db x=125 y=410 c=0,0,100 w=101 h=40 t="Stop reading" a="TIM s=0";', echo=True)
    et.transceive('db x=230 y=410 c=0,0,100 w=50 h=40 t="Read all" a="G0 is=?+G1 is=?+G2 is=?+G3 is=?+G4 is=?+G5 is=?+G6 is=?+G7 is=?+G8 is=?";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)
    
    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
